@@ -114,6 +114,13 @@ def create_xml_file(root_node_tag, output_file):
 
     xml = etree.Element(root_node_tag)
     tree = etree.ElementTree(xml)
+
+    # create dir if not exists
+    from os_file_handler import file_handler
+    parent_dir = file_handler.get_parent_path(output_file)
+    if not file_handler.is_dir_exists(parent_dir):
+        file_handler.create_dir(parent_dir)
+
     save_xml_file(tree, output_file)
     # tree = read_xml_file(output_file)   # maybe to read the xml again, to prevent the comments from being removed?
     return tree
@@ -174,6 +181,8 @@ def merge_xml1_with_xml2(xml1, xml2):
             add_node(xml1_root, xml2_child)
 
     return xml1
+
+
 #
 # # will merge xml1 with xml2 and return a new xml comprising both of them.
 # # NOTICE: this function will compare the direct root child nodes and merge/append them.
@@ -228,7 +237,6 @@ def set_node_atts(node, atts_dict, namespace_map=None):
 
 # will search for a node
 def find_all_nodes(parent_node, node_tag, node_att_name=None, node_att_val=None, recursive=True, namespace_map=None):
-
     selector = node_tag
     if node_att_name is not None:
         node_att_name = _sanitize_att_name(node_att_name, namespace_map)
@@ -247,6 +255,6 @@ def _sanitize_att_name(att_name, namespace_map):
     if namespace_map is not None:
         for prefix, uri in namespace_map.items():
             if prefix in att_name:
-                att_name =  '{' + str(att_name).replace(':','}').replace(prefix, uri)
+                att_name = '{' + str(att_name).replace(':', '}').replace(prefix, uri)
                 break
-    return att_name
\ No newline at end of file
+    return att_name
